@@ -11,12 +11,14 @@ datadir = sys.argv[1]
 destdir = os.environ.get('DESTDIR', '')
 bindir = os.path.normpath(destdir + os.sep + sys.argv[2])
 
+appid = sys.argv[3];
+
 # FIXME: meson will not track the creation of these files
 #        https://github.com/mesonbuild/meson/blob/master/mesonbuild/scripts/uninstall.py#L39
 if not os.path.exists(bindir):
   os.makedirs(bindir)
 
-src = os.path.join(datadir, 'gnome-maps', 'org.gnome.Maps')
+src = os.path.join(datadir, 'gnome-maps', appid)
 dest = os.path.join(bindir, 'gnome-maps')
 subprocess.call(['ln', '-s', '-f', src, dest])
 
