@@ -86,13 +86,17 @@ var MainWindow = GObject.registerClass({
                         'noNetworkView',
                         'actionBar',
                         'actionBarRevealer',
-                        'placeBarContainer' ]
+                        'placeBarContainer']
 }, class MainWindow extends Gtk.ApplicationWindow {
 
     get mapView() {
         return this._mapView;
     }
 
+    get placeEntry() {
+        return this._placeEntry;
+    }
+
     _init(params) {
         super._init(params);
 
@@ -112,6 +116,9 @@ var MainWindow = GObject.registerClass({
         this._contextMenu = new ContextMenu.ContextMenu({ mapView: this._mapView,
                                                           mainWindow: this });
 
+        if (pkg.name.endsWith('.Devel'))
+            this.get_style_context().add_class('devel');
+
         this._initActions();
         this._initHeaderbar();
         this._initSignals();
@@ -592,7 +599,7 @@ var MainWindow = GObject.registerClass({
             program_name: _("Maps"),
             comments: _("A map application for GNOME"),
             license_type: Gtk.License.GPL_2_0,
-            logo_icon_name: 'org.gnome.Maps',
+            logo_icon_name: pkg.name,
             version: pkg.version,
             website: 'https://live.gnome.org/Apps/Maps',
             wrap_license: true,
