@@ -36,6 +36,7 @@ const OSMTypes = imports.osmTypes;
 const OSMTypeSearchEntry = imports.osmTypeSearchEntry;
 const OSMUtils = imports.osmUtils;
 const Utils = imports.utils;
+const Wikipedia = imports.wikipedia;
 
 var Response = {
     UPLOADED: 0,
@@ -84,6 +85,21 @@ var _osmPhoneRewriteFunc = function(text) {
     }
 };
 
+/* Reformat an e-mail address if it it looks like a mailto: URI
+ * strip off the leading mailto: protocol string and trailing parameters,
+ * following a ?
+ * otherwise return the string unmodified
+ */
+var _osmEmailRewriteFunc = function(text) {
+    if (GLib.uri_parse_scheme(text) === 'mailto') {
+        let afterMailto = text.replace('mailto:', '');
+
+        return Soup.uri_decode(afterMailto.split('?')[0]);
+    } else {
+        return text;
+    }
+}
+
 /*
  * specification of OSM edit fields
  * name: the label for the edit field (translatable)
@@ -120,6 +136,8 @@ const OSM_FIELDS = [
         name: _("Website"),
         tag: 'website',
         type: EditFieldType.TEXT,
+        validate: Utils.isValidWebsite,
+        validateError: _("This is not a valid URL. Make sure to include http:// or https://."),
         hint: _("The official website. Try to use the most basic form " +
                 "of a URL i.e. http://example.com instead of " +
                 "http://example.com/index.html.")
@@ -133,10 +151,21 @@ const OSM_FIELDS = [
                 "starting with a + sign. Beware of local privacy " +
                 "laws, especially for private phone numbers.")
     },
+    {
+        name: _("E-mail"),
+        tag: 'email',
+        type: EditFieldType.TEXT,
+        validate: Utils.isValidEmail,
+        rewriteFunc: this._osmEmailRewriteFunc,
+        validateError: _("This is not a valid e-mail address. Make sure to not include the mailto: protocol prefix."),
+        hint: _("Contact e-mail address for inquiries. " +
+                "Add only email addresses that are intended to be publicly used.")
+    },
     {
         name: _("Wikipedia"),
         tag: 'wikipedia',
         type: EditFieldType.TEXT,
+        validate: Wikipedia.isValidWikipedia,
         rewriteFunc: this._osmWikipediaRewriteFunc,
         hint: _("The format used should include the language code " +
                 "and the article title like “en:Article title”.")
@@ -180,6 +209,14 @@ const OSM_FIELDS = [
                   ['terminal', _("Terminal")],
                   ['service', _("Service")]]
     },
+    {
+        name: _("Takeaway"),
+        tag:  'takeaway',
+        type: EditFieldType.COMBO,
+        options: [['yes', _("Yes")],
+                  ['no', _("No")],
+                  ['only', _("Only")]]
+    },
     {
         name: _("Religion"),
         tag: 'religion',
@@ -457,7 +494,7 @@ var OSMEditDialog = GObject.registerClass({
             let children = this._recentTypesListBox.get_children();
 
             for (let i = 0; i < children.length; i++) {
-                children[i].destroy();
+                this._recentTypesListBox.remove(children[i]);
             }
 
             this._recentTypesLabel.visible = true;
@@ -468,7 +505,6 @@ var OSMEditDialog = GObject.registerClass({
                 let value = recentTypes[i].value;
                 let title = OSMTypes.lookupType(key, value);
 
-                let row = new Gtk.ListBoxRow({visible: true, hexpand: true});
                 let grid = new Gtk.Grid({visible: true,
                                          margin_top: 6, margin_bottom: 6,
                                          margin_start: 12, margin_end: 12});
@@ -477,14 +513,15 @@ var OSMEditDialog = GObject.registerClass({
 
                 label.get_style_context().add_class('dim-label');
 
+                grid.attach(label, 0, 0, 1, 1);
+
+                this._recentTypesListBox.insert(grid, -1);
+
+                let row = this._recentTypesListBox.get_row_at_index(i);
+
                 row._title = title;
                 row._key = key;
                 row._value = value;
-
-                row.add(grid);
-                grid.add(label);
-
-                this._recentTypesListBox.add(row);
             }
         } else {
             this._recentTypesLabel.visible = false;
@@ -620,6 +657,20 @@ var OSMEditDialog = GObject.registerClass({
         }
     }
 
+    _validateTextEntry(fieldSpec, entry) {
+        if (fieldSpec.validate) {
+            /* also allow empty text without showing the validation warning,
+             * since we want to allow clearing out the text to unset a value
+             * (equivalent to using the delete button).
+             */
+            if (entry.text !== '' && !fieldSpec.validate(entry.text)) {
+                entry.get_style_context().add_class("warning");
+            } else {
+                entry.get_style_context().remove_class("warning");
+            }
+        }
+    }
+
     _addOSMEditTextEntry(fieldSpec, value) {
         this._addOSMEditLabel(fieldSpec);
 
@@ -633,13 +684,23 @@ var OSMEditDialog = GObject.registerClass({
             if (fieldSpec.rewriteFunc)
                 entry.text = fieldSpec.rewriteFunc(entry.text);
             this._osmObject.set_tag(fieldSpec.tag, entry.text);
+
+            this._validateTextEntry(fieldSpec, entry);
+
             this._nextButton.sensitive = true;
         });
 
+        this._validateTextEntry(fieldSpec, entry);
+
         if (fieldSpec.hint) {
             entry.secondary_icon_name = 'dialog-information-symbolic';
             entry.connect('icon-press', (entry, iconPos, event) => {
-                this._showHintPopover(entry, fieldSpec.hint);
+                if (fieldSpec.validate && entry.text !== '' &&
+                    !fieldSpec.validate(entry.text)) {
+                    this._showHintPopover(entry, fieldSpec.validateError);
+                } else {
+                    this._showHintPopover(entry, fieldSpec.hint);
+                }
             });
         }
 
@@ -739,6 +800,7 @@ var OSMEditDialog = GObject.registerClass({
         }
 
         /* add selectable items */
+        let row = 0;
         for (let i = 0; i < OSM_FIELDS.length; i++) {
             let fieldSpec = OSM_FIELDS[i];
             let hasValue = false;
@@ -779,7 +841,8 @@ var OSMEditDialog = GObject.registerClass({
                 });
 
                 hasAllFields = false;
-                this._addFieldPopoverGrid.add(button);
+                this._addFieldPopoverGrid.attach(button, 0, row, 1, 1);
+                row++;
             }
         }
 
