@@ -34,6 +34,7 @@ const Location = imports.location;
 const Place = imports.place;
 const PlaceStore = imports.placeStore;
 const PlacePopover = imports.placePopover;
+const URIS = imports.uris;
 const Utils = imports.utils;
 
 // minimum number of characters to start completion
@@ -117,6 +118,8 @@ var PlaceEntry = GObject.registerClass({
 
         // clear cache when view moves, as result are location-dependent
         this._mapView.view.connect('notify::latitude', () => this._cache = {});
+        // clear cache when zoom level changes, to allow limiting location bias
+        this._mapView.view.connect('notify::zoom-level', () => this._cache =  {});
     }
 
     _onSearchChanged() {
@@ -127,7 +130,7 @@ var PlaceEntry = GObject.registerClass({
         if (this._cancellable)
             return;
 
-        /* start search if more than the threashold number of characters have
+        /* start search if more than the threshold number of characters have
          * been entered, or if the first character is in the ideographic CJK
          * block, as for these, shorter strings could be meaningful
          */
@@ -137,7 +140,7 @@ var PlaceEntry = GObject.registerClass({
             let cachedResults = this._cache[this.text];
 
             if (cachedResults) {
-                this._updateResults(cachedResults);
+                this.updateResults(cachedResults, this.text, true);
             } else {
                 // if no previous search has been performed, show spinner
                 if (!this._previousSearch ||
@@ -199,6 +202,15 @@ var PlaceEntry = GObject.registerClass({
             return false;
     }
 
+    /**
+     * Returns true if two locations are equal when rounded to displayes
+     * coordinate precision
+     */
+    _roundedLocEquals(locA, locB) {
+        return '%.5f, %.5f'.format(locA.latitude, locA.longitude) ===
+               '%.5f, %.5f'.format(locB.latitude, locB.longitude)
+    }
+
     _parse() {
         let parsed = false;
 
@@ -216,9 +228,29 @@ var PlaceEntry = GObject.registerClass({
             parsed = true;
         }
 
+        if (this.text.startsWith('maps:')) {
+            let query = URIS.parseMapsURI(this.text);
+
+            if (query) {
+                this.text = query;
+            } else {
+                let msg = _("Failed to parse Maps URI");
+                Utils.showDialog(msg, Gtk.MessageType.ERROR, this.get_toplevel());
+            }
+
+            parsed = true;
+        }
+
         let parsedLocation = Place.Place.parseCoordinates(this.text);
         if (parsedLocation) {
-            this.place = new Place.Place({ location: parsedLocation });
+            /* if the place was a parsed OSM coordinate URL, it will have
+             * gotten re-written as bare coordinates and trigger a search-changed,
+             * in this case don't re-set the place, as it will loose the zoom
+             * level from the URL if set
+             */
+            if (!this.place ||
+                !this._roundedLocEquals(parsedLocation, this.place.location))
+                this.place = new Place.Place({ location: parsedLocation });
             parsed = true;
         }
 
@@ -252,9 +284,18 @@ var PlaceEntry = GObject.registerClass({
             this._cancellable.cancel();
         this._cancellable = new Gio.Cancellable();
         this._previousSearch = this.text;
-        GeocodeFactory.getGeocoder().search(this.text,
-                                            this._mapView.view.latitude,
-                                            this._mapView.view.longitude,
+
+        /* as a stop-gap solution for the location bias tuning issues
+         * in Photon (https://github.com/komoot/photon/issues/600),
+         * for now search "globally" (e.g. without location bias) for
+         * zoom levels above 17, to still allow focused search nearby
+         */
+        let lat = this._mapView.view.zoom_level > 17 ?
+                  this._mapView.view.latitude : null;
+        let lon = this._mapView.view.zoom_level > 17 ?
+                  this._mapView.view.longitude : null;
+
+        GeocodeFactory.getGeocoder().search(this.text, lat, lon,
                                             this._cancellable,
                                             (places, error) => {
             this._cancellable = null;
@@ -263,7 +304,7 @@ var PlaceEntry = GObject.registerClass({
                 this.place = null;
                 this._popover.showError();
             } else {
-                this._updateResults(places);
+                this.updateResults(places, this.text, true);
 
                 // cache results for later
                 this._cache[this._previousSearch] = places;
@@ -275,7 +316,14 @@ var PlaceEntry = GObject.registerClass({
         });
     }
 
-    _updateResults(places) {
+    /**
+     * Update results popover
+     * places array of places from search result
+     * searchText original search string to highlight in results
+     * includeContactsAndRoute whether to include contacts and recent routes
+     *                         among results
+     */
+    updateResults(places, searchText, includeContactsAndRoutes) {
         if (!places) {
                 this.place = null;
                 this._popover.showNoResult();
@@ -285,13 +333,15 @@ var PlaceEntry = GObject.registerClass({
         let completedPlaces = [];
 
 
-        this._filter.refilter();
-        this._filter.foreach((model, path, iter) => {
-            let place = model.get_value(iter, PlaceStore.Columns.PLACE);
-            let type = model.get_value(iter, PlaceStore.Columns.TYPE);
+        if (includeContactsAndRoutes) {
+            this._filter.refilter();
+            this._filter.foreach((model, path, iter) => {
+                let place = model.get_value(iter, PlaceStore.Columns.PLACE);
+                let type = model.get_value(iter, PlaceStore.Columns.TYPE);
 
-            completedPlaces.push({ place: place, type: type });
-        });
+                completedPlaces.push({ place: place, type: type });
+            });
+        }
 
         let placeStore = Application.placeStore;
 
@@ -308,7 +358,7 @@ var PlaceEntry = GObject.registerClass({
             completedPlaces.push({ place: place, type: type });
         });
 
-        this._popover.updateResult(completedPlaces, this.text);
+        this._popover.updateResult(completedPlaces, searchText);
         this._popover.showResult();
     }
 });
