@@ -31,6 +31,7 @@ const Application = imports.application;
 const ContactPlace = imports.contactPlace;
 const Overpass = imports.overpass;
 const Place = imports.place;
+const PlaceIcons = imports.placeIcons;
 const PlaceViewImage = imports.placeViewImage;
 const PlaceButtons = imports.placeButtons;
 const PlaceFormatter = imports.placeFormatter;
@@ -131,7 +132,7 @@ var PlaceView = GObject.registerClass({
         this._placeDetails = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL,
                                            visible: true,
                                            hexpand: true });
-        this.content.add(this._placeDetails);
+        this.content.attach(this._placeDetails, 0, 0, 1, 1);
 
         if (this.place.isCurrentLocation) {
             this._populate(this.place);
@@ -303,6 +304,43 @@ var PlaceView = GObject.registerClass({
             content.push(phone);
         }
 
+        if (place.email && Utils.isValidEmail(place.email)) {
+            content.push({ label: _("E-mail"),
+                           icon: 'mail-unread-symbolic',
+                           info: GLib.markup_escape_text(place.email, -1),
+                           linkUrl: 'mailto:%s'.format(place.email) });
+        }
+
+        if (place.isEatingAndDrinking) {
+            switch (place.takeaway) {
+                case 'yes':
+                    /* Translators:
+                     * The establishment offers customers to purchase meals
+                     * (or similar) to be consumed elsewhere
+                     */
+                    content.push({ info: _("Offers takeaway"),
+                                   icon: PlaceIcons.getIconForPlace(place) });
+                    break;
+                case 'no':
+                    /* Translators:
+                     * The establishment only offers customers to purchase
+                     * meals (or similar) to be consumed on-premise.
+                     */
+                    content.push({ info: _("Does not offer takeaway"),
+                                   icon: PlaceIcons.getIconForPlace(place) });
+                    break;
+                case 'only':
+                    /* Translators:
+                     * The establishment only offers customers to purchase
+                     * meals (or similar) to be consumed elsewhere. E.g.
+                     * there is no seating on-premise for eating/drinking
+                     */
+                    content.push({ info: _("Only offers takeaway"),
+                                   icon: PlaceIcons.getIconForPlace(place) });
+                    break;
+            }
+        }
+
         if (place.openingHours) {
             content.push({ label: _("Opening hours"),
                            icon: 'emoji-recent-symbolic',
@@ -416,16 +454,36 @@ var PlaceView = GObject.registerClass({
              */
             content.push({ label: _("Population"),
                            icon: 'system-users-symbolic',
-                           info: parseInt(place.population).toLocaleString() });
+                           info: Utils.prettyPopulation(parseInt(place.population)) });
         }
 
         /* The default value for a place's altitude is -G_MAXDOUBLE, so we can
          * compare to an impossibly low altitude to see if one is set */
         if (place.location.altitude > -1000000000.0) {
             let alt  = place.location.altitude;
+            let info;
+
+            if (alt > 0) {
+                info = Utils.prettyDistance(alt, true);
+            } else if (alt < 0) {
+                /**
+                 * Translators: this is a label indicating an altitude below
+                 * sea level, where the %s placeholder is the altitude relative
+                 * to mean sea level in the "negative direction"
+                 */
+                info = _("%s below sea level").
+                            format(Utils.prettyDistance(-alt, true));
+            } else {
+                /**
+                 * Translators: this indicates a place is located at (or very
+                 * close to) mean sea level
+                 */
+                info = _("At sea level");
+            }
+
             content.push({ label: _("Altitude"),
                            icon: 'mountain-symbolic',
-                           info: Utils.prettyDistance(alt, true) });
+                           info: info });
         }
 
         if (place.religion) {
@@ -433,7 +491,7 @@ var PlaceView = GObject.registerClass({
                            info: Translations.translateReligion(place.religion) });
         }
 
-        if (place.wiki) {
+        if (place.wiki && Wikipedia.isValidWikipedia(place.wiki)) {
             content.push({ type: 'wikipedia', info: '' });
         }
 
@@ -548,7 +606,7 @@ var PlaceView = GObject.registerClass({
         let content = this._createContent(place);
         this._attachContent(content);
 
-        if (place.wiki) {
+        if (place.wiki && Wikipedia.isValidWikipedia(place.wiki)) {
             this._requestWikipedia(place.wiki);
         }
 
@@ -590,7 +648,7 @@ var PlaceView = GObject.registerClass({
 
     // clear the view widgets to be able to re-populate an updated place
     _clearView() {
-        this._placeDetails.get_children().forEach((child) => child.destroy());
+        this._placeDetails.get_children().forEach((child) => this._placeDetails.remove(child));
     }
 
     // called when the place's location changes (e.g. for the current location)
